\name{Digamma}
\alias{Digamma}
\alias{canonic.digamma}
\alias{d2cumulant.digamma}
\alias{unitdeviance.digamma}
\alias{cumulant.digamma}
\alias{meanval.digamma}
\alias{varfun.digamma}
\title{Digamma generalized linear model family}
\description{
Produces a Digamma generalized linear model family object. The Digamma distribution is the
distribution of the unit deviance for a gamma response.
}
\usage{
Digamma(link = "log")
unitdeviance.digamma(y, mu)
cumulant.digamma(theta)
meanval.digamma(theta)
d2cumulant.digamma(theta)
varfun.digamma(mu)
canonic.digamma(mu)
}
\arguments{
  \item{link}{character string, number or expressing specifying the link function. See \code{quasi} for specification of this argument.}
  \item{y}{numeric vector of (positive) response values}
  \item{mu}{numeric vector of (positive) fitted values}
  \item{theta}{numeric vector of values of the canonical variable, equal to \eqn{-1/\phi} where \eqn{\phi} is the dispersion parameter of the gamma distribution}
}
\value{
\code{Digamma} produces a glm family object, which is a list of functions and expressions used by \code{glm} in its iteratively reweighted least-squares algorithm. See \code{family} for details.

The other functions take vector arguments and produce vector values of the same length and called by \code{Digamma}.
\code{unitdeviance.digamma} gives the unit deviances of the family, equal to the squared deviance residuals.
\code{cumulant.digamma} is the cumulant function.  If the dispersion is unity, then successive derivatives of the cumulant function give successive cumulants of the Digamma distribution.  \code{meanvalue.digamma} gives the first derivative, which is the expected value.
\code{d2cumulant.digamma} gives the second derivative, which is the variance.
\code{canonic.digamma} is the inverse of \code{meanvalue.digamma} and gives the canonical parameter as a function of the mean parameter.
\code{varfun.digamma} is the variance function of the Digamma family, the variance as a function of the mean.
}
\details{
This family is useful for dispersion modelling with gamma generalized linear models.
The Digamma distribution describes the distribution of the unit deviances for a gamma family, in the same way that the gamma distribution itself describes the distribution of the unit deviances for Gaussian or inverse Gaussian families.
The Digamma distribution is so named because it is dual to the gamma distribution in the above sense, and because the \code{digamma function} appears in its mean function.

Suppose that \eqn{y} follows a gamma distribution with mean \eqn{\mu} and dispersion parameter \eqn{\phi}, so the variance of \eqn{y} is \eqn{\phi \mu^2}.
Write \eqn{d(y,\mu)} for the gamma distribution unit deviance.
Then \code{meanval.digamma(-1/phi)} gives the mean of \eqn{d(y,\mu)} and \code{2*d2cumulant.digamma(-1/phi)} gives the variance.
}

\author{Gordon Smyth}

\references{
Smyth, G. K. (1989). Generalized linear models with varying dispersion. \emph{J. R. Statist. Soc. B}, \bold{51}, 47-61.
}
\examples{
# Test for log-linear dispersion trend in gamma regression
y <- rchisq(20,df=1)
x <- 1:20
out.gam <- glm(y~x,family=Gamma(link="log"))
d <- residuals(out.gam)^2
out.dig <- glm(d~x,family=Digamma(link="log"))
summary(out.dig,dispersion=2)
}
\seealso{
\code{\link[base:family]{quasi}}, \code{\link[base]{make.link}}
}
\keyword{models}
\eof
\name{fisher.test2}
\alias{fisher.test2}

\title{Fast Version of Fisher's Exact Test for Count Data}

\description{
Performs Fisher's exact test for testing the null of independence of rows and columns in a contingency table with fixed marginals.
This is a cut down version of \code{fisher.test} in the \code{ctest} package.
}

\usage{
fisher.test2(x, workspace=2e+05)
}

\arguments{
\item{x}{numeric matrix containing contingency table counts}
\item{workspace}{an integer specifying the size of the workspace used in the network algorithm}
}

\value{
Numeric vector of p-values.
}

\author{Gordon Smyth}

\seealso{
\code{\link[ctest]{fisher.test}}
}

\examples{
fisher.test2(matrix(c(0,100,20,100),2,2))
}

\keyword{htest}
\eof
\name{gauss.quad}
\alias{gauss.quad}
\title{Gaussian Quadrature}

\description{Calculate nodes and weights for Gaussian quadrature.}

\usage{gauss.quad(n,kind="legendre",alpha=0,beta=0)}

\arguments{
  \item{n}{number of nodes and weights}
  \item{kind}{kind of Gaussian quadrature, one of \code{"legendre"}, \code{"chebyshev1"}, \code{"chebyshev2"}, \code{"hermite"}, \code{"jacobi"} or \code{"laguerre"}}
  \item{alpha}{parameter for Jacobi or Laguerre quadrature, must be greater than -1}
  \item{beta}{parameter for Jacobi quadrature, must be greater than -1}
}

\value{A list containing the components
  \item{nodes}{vector of values at which to evaluate the function}
  \item{weights}{vector of weights to give the function values}
}

\details{
The integral from \code{a} to \code{b} of \code{w(x)*f(x)} is approximated by \code{sum(w*f(x))} where \code{x} is the vector of nodes and \code{w} is the vector of weights.  The approximation is exact if \code{f(x)} is a polynomial of order no more than \code{2n+1}.
The possible choices for \code{w(x)}, \code{a} and \code{b} are as follows:

Legendre quadrature: \code{w(x)=1} on \code{(-1,1)}.

Chebyshev quadrature of the 1st kind: \code{w(x)=1/sqrt(1-x^2)} on \code{(-1,1)}.

Chebyshev quadrature of the 2nd kind: \code{w(x)=sqrt(1-x^2)} on \code{(-1,1)}.

Hermite quadrature: \code{w(x)=exp(-x^2)} on \code{(-Inf,Inf)}.

Jacobi quadrature: \code{w(x)=(1-x)^alpha*(1+x)^beta} on \code{(-1,1)}. Note that Chebyshev quadrature is a special case of this.

Laguerre quadrature: \code{w(x)=x^alpha*exp(-x)} on \code{(0,Inf)}.

The method is explained in Golub and Welsch (1969).
}

\note{
This function solves a dense \code{n}x\code{n} eigenvector problem and is therefore slow for large \code{n}.
It could be made far more efficient by using an eigenvector function designed to compute the leading terms of the eigenvectors for tridiagonal matrices.
}

\references{
Golub, G. H., and Welsch, J. H. (1969). Calculation of Gaussian
quadrature rules. \emph{Mathematics of Computation} \bold{23}, 221-230.

Golub, G. H. (1973). Some modified matrix eigenvalue problems.
\emph{Siam Review} \bold{15}, 318-334.

Stroud and Secrest (1966). \emph{Gaussian Quadrature Formulas}. Prentice-
Hall, Englewood Cliffs, N.J.
}

\author{Gordon Smyth}

\seealso{
\code{\link[statmod:gauss.quad.prob]{gauss.quad.prob}}, \code{\link[base:integrate]{integrate}}
}

\examples{
out <- gauss.quad(10,"laguerre",alpha=5)
sum(out$weights * out$nodes) / gamma(6)
#  mean of gamma distribution with alpha=6
}
\keyword{math}
\eof
\name{gauss.quad.prob}
\alias{gauss.quad.prob}
\title{Gaussian Quadrature with Probability Distributions}

\description{Calculate nodes and weights for Gaussian quadrature in terms of probability distributions.}

\usage{gauss.quad.prob(n,dist="uniform",l=0,u=1,mu=0,sigma=1,alpha=1,beta=1)}

\arguments{
  \item{n}{number of nodes and weights}
  \item{dist}{distribution that Gaussian quadrature is based on, one of \code{"uniform"}, \code{"normal"}, \code{"beta"} or \code{"gamma"}}
  \item{l}{lower limit of uniform distribution}
  \item{u}{upper limit of uniform distribution}
  \item{mu}{mean of normal distribution}
  \item{sigma}{standard deviation of normal distribution}
  \item{alpha}{positive shape parameter for beta or gamma distribution}
  \item{beta}{positive scale parameter for gamma distribution}
}

\value{A list containing the components
  \item{nodes}{vector of values at which to evaluate the function}
  \item{weights}{vector of weights to give the function values}
}

\details{
This is a rewriting and simplification of \code{gauss.quad} in terms of probability distributions.

The expected value of \code{f(X)} is approximated by \code{sum(w*f(x))} where \code{x} is the vector of nodes and \code{w} is the vector of weights.  The approximation is exact if \code{f(x)} is a polynomial of order no more than \code{2n+1}.
The possible choices for the distribution of \code{X} are as follows:

Uniform on \code{(l,u)}.

Normal with mean \code{mu} and standard deviation \code{sigma}.

Beta with density \code{x^(alpha-1)*(1-x)^(beta-1)/B(alpha,beta)} on \code{(0,1)}.

Gamma with density \code{x^(alpha-1)*exp(-x/beta)/beta^alpha/gamma(alpha)}.
}

\references{
Golub, G. H., and Welsch, J. H. (1969). Calculation of Gaussian
quadrature rules. \emph{Mathematics of Computation} \bold{23}, 221-230.

Golub, G. H. (1973). Some modified matrix eigenvalue problems.
\emph{Siam Review} \bold{15}, 318-334.

Stroud and Secrest (1966). \emph{Gaussian Quadrature Formulas}. Prentice-
Hall, Englewood Cliffs, N.J.
}

\author{Gordon Smyth}

\seealso{
\code{\link[statmod:gauss.quad]{gauss.quad}}, \code{\link[base:integrate]{integrate}}
}

\examples{
out <- gauss.quad.prob(10,"normal")
sum(out$weights * out$nodes^4)
#  the 4th moment of the standard normal is 3

out <- gauss.quad.prob(32,"gamma",alpha=5)
sum(out$weights * log(out$nodes))
#  the expected value of log(X) where X is gamma is digamma(alpha)
}
\keyword{math}
\eof
\name{glmgam.fit}
\alias{glmgam.fit}
\title{Gamma Generalized Linear Model with Identity Link}
\description{
Estimates a gamma generalized linear model with identity link using Fisher scoring with Levenberg damping.
}
\usage{
glmgam.fit(X,y,start=NULL,trace=FALSE,tol=1e-5,maxit=50)
}
\arguments{
  \item{X}{design matrix, assumed to be of full column rank.  Missing values not allowed.}
  \item{y}{numeric vector of responses. Missing values not allowed.}
  \item{start}{numeric vector of starting values for the regression coefficients}
  \item{trace}{Logical variable. If true then output diagnostic information at each iteration.}
  \item{tol}{Convergence tolerance}
  \item{maxit}{Maximum number of iterations allowed}
}
\value{
List with the following components:
  \item{coefficients}{numeric vector of regression coefficients}
  \item{fitted}{numeric vector of fitted values}
  \item{deviance}{residual deviance}
}
\item{details}
This function is similar to \code{glm.fit(X,y,family=Gamma(link="identity"))} but has more secure convergence.

This function is used by \code{randomizedBlockFit}.
}
\examples{
y <- rgamma(10,shape=5)
X <- cbind(1,1:10)
fit <- glmgam.fit(X,y,trace=TRUE)
}
\keyword{regression}
\eof
\name{growthcurve}
\alias{compareGrowthCurves}
\alias{compareTwoGrowthCurves}

\title{Compare Groups of Growth Curves}
\description{
Do all pairwise comparisons between groups of growth curves using a permutation test. 
}

\usage{
compareGrowthCurves(group,y,levels=NULL,nsim=100,fun=meanT,times=NULL,verbose=TRUE,adjust="holm")
compareTwoGrowthCurves(group,y,nsim=100,fun=meanT)
}

\arguments{
\item{group}{vector or factor indicating group membership.  Missing values are allowed in \code{compareGrowthCurves} but not in \code{compareTwoGrowthCurves}.}
\item{y}{matrix of response values with rows for individuals and columns for times.  The number of rows must agree with the length of \code{group}. Missing values are allowed.}
\item{levels}{a character vector containing the identifiers of the groups to be compared.  By default all groups with two more more members will be compared.}
\item{nsim}{number of permutations to estimated p-values.}
\item{fun}{the statistic used to measure the distance between two groups of growth curves.
Default to a mean t-statistic.}
\item{times}{a numeric vector containing the column numbers on which the groups should be compared.
By default all the columns are used.}
\item{verbose}{should progress results be printed?}
\item{adjust}{method used to adjust for multiple testing, see \code{p.adjust}.}
}

\details{
\code{compareTwoGrowthCurves} performs a permutation test of the difference between two groups of growth curves.
\code{compareGrowthCurves} does all pairwise comparisons between two or more groups of growth curves.
Accurate p-values can be obtained by setting \code{nsim} to some large value, \code{nsim=10000} say.
}

\value{
\code{compareTwoGrowthCurves} returns a list with two components, \code{stat} and \code{p.value}, containing the observed statistics and the estimated p-value.  \code{compareGrowthCurves} returns a data frame with components
\item{Group1}{name of first group in a comparison}
\item{Group2}{name of second group in a comparison}
\item{Stat}{observed value of the statistic}
\item{P.Value}{estimated p-value}
\item{adj.P.Value}{p-value adjusted for multiple testing}
}

\author{Gordon Smyth}

\seealso{
\code{\link{compareGrowthCurves}}, \code{\link{compareTwoGrowthCurves}}
}

\examples{
# A example with only one time
data(PlantGrowth)
compareGrowthCurves(PlantGrowth$group,as.matrix(PlantGrowth$weight))
# Can make p-values more accurate by nsim=10000
}

\keyword{regression}
\eof
\name{hommel.test}
\alias{hommel.test}
\title{Test Multiple Comparisons}

\description{Given a set of p-values and a test level, returns test results for each of the hypotheses.}

\usage{hommel.test(p, alpha=0.05)
}

\arguments{
  \item{p}{vector of p-values}
  \item{alpha}{desired significance level}
}

\value{A logical vector indicating whether each hypothesis is accepted.}

\details{
This function implements the multiple testing procedure of Hommel (1988).
Hommel's method is also implemented as an adjusted P-value method in the function \code{p.adjust} but the accept/reject approach in this function is faster.
}

\references{
Hommel, G. (1988). A stagewise rejective multiple test procedure based on a modified Bonferroni test. \emph{Biometrika}, \bold{75}, 383-386.

Shaffer, J. P. (1995). Multiple hypothesis testing. \emph{Annual Review of Psychology} \bold{46}, 561-576. (An excellent review of the area.)
}

\author{Gordon Smyth}

\seealso{
\code{\link[statmod:p.adjust]{p.adjust}}
}

\examples{
p <- sort(runif(100))[1:10]
cbind(p,p.adjust(p,"hommel"),hommel.test(p))
}
\keyword{htest}
\eof
\name{invgauss}
\alias{dinvgauss}
\alias{pinvgauss}
\alias{qinvgauss}
\alias{rinvgauss}
\title{Inverse Gaussian Distribution}

\description{
Density, cumulative probability, quantiles and random generation for the inverse Gaussian distribution.
}

\usage{
dinvgauss(x, mu, lambda=1)
pinvgauss(q, mu, lambda=1)
qinvgauss(p, mu, lambda=1)
rinvgauss(n, mu, lambda=1)
}

\arguments{
  \item{x}{vector of quantiles. Missing values (NAs) are allowed.}
  \item{q}{vector of quantiles. Missing values (NAs) are allowed.}
  \item{p}{vector of probabilities. Missing values (NAs) are allowed.}
  \item{n}{sample size. If \code{length(n)} is larger than 1, then \code{length(n)} random values are returned.}
  \item{mu}{vector of (positive) means. This is replicated to be the same length as \code{p} or \code{q} or the number of deviates generated.}
  \item{lambda}{vector of (positive) precision parameters. This is replicated to be the same length as \code{p} or \code{q} or the number of deviates generated.}
}

\value{
Vector of same length as \code{x} or \code{q} giving the density (\code{dinvgauss}), probability (\code{pinvgauss}), quantile (\code{qinvgauss}) or random sample (\code{rinvgauss}) for the inverse
Gaussian distribution with mean \code{mu} and inverse dispersion \code{lambda}.
Elements of \code{q} or \code{p} that are missing will cause the corresponding elements of
the result to be missing.
}

\details{
The inverse Gaussian distribution takes values on the positive real line. The variance of the distribution is $\mu^3/\lambda$. Applications of the inverse Gaussian include sequential analysis, diffusion processes and radiotechniques. The inverse Gaussian is one of the response distributions used in generalized linear models.
}
 
\references{
Chhikara, R. S., and Folks, J. Leroy, (1989). \emph{The inverse Gaussian distribution: Theory, methodology, and  applications}. Marcel Dekker, New York.
}

\author{Gordon Smyth and Dr Paul Bagshaw, Centre National d'Etudes des Telecommunications (DIH/DIPS), France (\code{qinvgauss})}

\seealso{
\code{\link{qres}}, \code{\link[base]{inverse.gaussian}}, \code{\link[base]{.Random.seed}} about random number generation.
}

\examples{
y <- rinvgauss(20,1,2) # generate vector of 20 random numbers
p <- pinvgauss(y,1,2) # p should be uniform</tt>
}

\keyword{distribution}
\eof
\name{logmdigamma}
\alias{logmdigamma}
\title{Log Minus Digamma Function}
\description{
The difference between the \code{log} and \code{digamma} functions.
}
\usage{
logmdigamma(x)
}
\arguments{
  \item{x}{numeric vector or array of positive values. Negative or zero values will return \code{NA}.}
}
\details{
\code{digamma(x)} is asymptotically equivalent to \code{log(x)}.  \code{logmdigamma(x)} computes \code{log(x) - digamma(x)} without subtractive cancellation for large \code{x}.
}
\author{Gordon Smyth}
\references{
Abramowitz, M., and Stegun, I. A. (1970). \emph{Handbook of
mathematical functions.} Dover, New York.
}
\seealso{
\code{\link[base:digamma]{digamma}}
}
\examples{
log(10^15) - digamma(10^15) # returns 0
logmdigamma(10^15) # returns value correct to 15 figures
}
\keyword{math}
\eof
\name{matvec}
\alias{matvec}
\alias{vecmat}

\title{Multiply a Matrix by a Vector}
\description{Multiply the rows or columns of a matrix by the elements of a vector.}

\usage{
matvec(M, v)
vecmat(v, M)
}

\arguments{
\item{M}{numeric matrix, or object which can be coerced to a matrix.}
\item{v}{numeric vector, or object which can be coerced to a vector. Length should match the number of columns of \code{M} (for \code{matvec}) or the number of rows of \code{M} (for \code{vecmat})}
}

\value{A matrix of the same dimensions as \code{M}.}

\details{
\code{matvec(M,v)} is equivalent to \code{M \%*\% diag(v)} but is faster to execute.
Similarly \code{vecmat(v,M)} is equivalent to \code{diag(v) \%*\% M} but is faster to execute.
}

\examples{
A <- matrix(1:12,3,4)
A
matvec(A,c(1,2,3,4))
vecmat(c(1,2,3),A)
}

\author{Gordon Smyth}

\keyword{array}
\keyword{algebra}
\eof
\name{meanT}
\alias{meanT}

\title{Mean t-Statistic Between Two Groups of Growth Curves}
\description{
The mean-t statistic of the distance between two groups of growth curves. 
}

\usage{
meanT(y1, y2)
}

\arguments{
\item{y1}{matrix of response values for the first group, with a row for each individual and a column for each time. Missing values are allowed.}
\item{y2}{matrix of response values for the second group.  Must have the same number of columns as \code{y1}. Missing values are allowed.}
}

\details{
This function computes the pooled two-sample t-statistic between the response values at each time, and returns the mean of these values weighted by the degrees of freedom.
This function is used by \code{compareGrowthCurves}.
}

\value{numeric vector of length one containing the mean t-statistic.}

\author{Gordon Smyth}

\seealso{
\code{\link{compareGrowthCurves}}, \code{\link{compareTwoGrowthCurves}}
}

\examples{
y1 <- matrix(rnorm(4*3),4,3)
y2 <- matrix(rnorm(4*3),4,3)
meanT(y1,y2)

data(PlantGrowth)
compareGrowthCurves(PlantGrowth$group,as.matrix(PlantGrowth$weight))
# Can make p-values more accurate by nsim=10000
}

\keyword{regression}
\eof
\name{mlreg}
\alias{mlreg}
\alias{mlreg.fit}
\alias{mlreg.fit.zero}

\title{Fit a Linear Model by Maximum Likelihood}
\description{
Fits a linear model by maximum likelihood assuming a variety of response
distributions. 
}

\usage{
mlreg.fit(X, y, weights=NULL, dist="logistic", init=NULL, scale=NULL)
mlreg.fit.zero(y, weights=NULL, dist="logistic", init=NULL, scale=NULL)
}

\arguments{
\item{X}{the design matrix. Rows containing missing values (in X or y) will be removed.}
\item{y}{numeric response vector. Missing values will be removed.}
\item{weights}{vector of non-negative weights.}
\item{dist}{character string giving the name of the response distribution. The possibilities are \code{"extreme"}, \code{"logistic"}, \code{"gaussian"}, \code{"weibull"}, \code{"exponential"}, \code{"rayleigh"},   
\code{"loggaussian"}, \code{"lognormal"}, \code{"loglogistic"} or \code{"t"} on 4 df. }
\item{init}{numeric vector of initial values for the parameters.}
\item{scale}{if specified then the scale parameter is fixed at the given value.}
}

\details{
This function is merely a convenient wrapper for calling the
\code{survreg.fit} function, which is part of the \code{survival} library by Terry Therneau.
It fits the model y = X*b + scale*e where b is the vector of regression coefficients and e is a vector of mean-zero errors, by maximum likelihood.

The function \code{mlreg.fit.zero} assumes that the mean is zero and fits y = scale*e, estimating only the scale parameter.
}

\value{See the documentation for \code{survreg.object}}

\author{Gordon Smyth}

\seealso{
\code{\link[survival:survreg]{survreg}}, \code{\link[survival:survreg.object]{survreg.object}}
}

\examples{
x <- 1:50
y <- x + 2*rnorm(50)
X <- cbind(1,x)
out <- mlreg.fit(X,y,dist="logistic")
}

\keyword{regression}
\eof
\name{power.fisher.test}
\alias{power.fisher.test}
\title{Power of Fisher's Exact Test for Comparing Proportions}
\description{
Calculate by simulation the power of Fisher's exact test for comparing two proportions given two margin counts. 
}

\usage{
power.fisher.test(p1, p2, n1, n2, alpha=0.05, nsim=100)
}

\arguments{
\item{p1}{first proportion to be compared}
\item{p2}{second proportion to be compared}
\item{n1}{first sample size}
\item{n2}{second sample size}
\item{alpha}{significance level}
\item{nsim}{number of simulated data sets}
}

\details{
Computes the power of Fisher's exact test for testing the null hypothesis that \code{p1} equals \code{p2} against the alternative that they are not equal.
}

\value{
Estimated power of the test
}

\author{Gordon Smyth}

\seealso{
\code{\link[ctest]{fisher.test}}, \code{\link[ctest]{power.t.test}}
}

\examples{
power.fisher.test(0.5,0.9,20,20) # 70% chance of detecting difference
}

\keyword{htest}
\eof
\name{qres}
\alias{qres}
\alias{qres.binom}
\alias{qres.pois}
\alias{qres.nbinom}
\alias{qres.gamma}
\alias{qres.invgauss}
\alias{qres.tweedie}
\title{Randomized Quantile Residuals}

\description{
Computes randomized quantile residuals for binomial,
Poisson, negative binomial, gamma and inverse Gaussian
generalized linear models.}

\usage{
qres.binom(glm.obj)
qres.pois(glm.obj)
qres.nbinom(glm.obj)
qres.gamma(glm.obj,dispersion=NULL)
qres.invgauss(glm.obj,dispersion=NULL)
qres.tweedie(glm.obj,dispersion=NULL)
}

\arguments{
\item{glm.obj}{Object of class \code{glm}. The generalized linear model family is assumed to be binomial for \code{qres.binom}, poisson for
\code{qres.pois}, negative binomial for \code{qres.nbinom}, Gamma for
\code{qres.gamma}, inverse Gaussian for \code{qres.invgauss} or
tweedie for \code{qres.tweedie}.}

\item{dispersion}{a positive real number. Specifies the value of the
dispersion parameter for a Gamma or inverse Gaussian generalized linear
model if known. If \code{NULL}, the dispersion will be estimated by its
Pearson estimator.}
}

\value{Numeric vector of standard normal quantile residuals.}

\details{
Quantile residuals are based on the idea of inverting the
estimated distribution function for each observation to
obtain exactly standard normal residuals. In the case of
discrete distributions, such as the binomial and Poisson,
some randomization is introduced to produce continuous
normal residuals. Quantile residuals are the residuals of
choice for generalized linear models in large dispersion
situations when the deviance and Pearson residuals can be
grossly non-normal. Quantile residuals are the only
useful residuals for binomial or Poisson data when the
response takes on only a small number of distinct values.
}
 
\references{
Dunn, K. P., and Smyth, G. K. (1996). Randomized quantile residuals. \emph{Journal of Computational and Graphical Statistics} \bold{5}, 1-10.
\url{http://www.statsci.org/smyth/pubs/residual.html}
}

\author{Gordon Smyth}

\seealso{\url{http://www.statsci.org/s/qres.html}, \code{\link[base:residuals.glm]{residuals.glm}}}

\examples{
y <- rpois(20,lambda=4)
x <- 1:20
fit <- glm(y~x,family="poisson")
qr <- qres.pois(fit)
qqnorm(qr)
qqline(qr)
}

\keyword{regression}
\eof
\name{ranblock}
\alias{randomizedBlock}
\alias{randomizedBlockFit}

\title{Randomized Block Mixed Linear Model}
\description{
Fits a mixed linear model by REML.  The linear model must contain only one random factor apart from the unit errors.
}

\usage{
randomizedBlock(formula, random, weights=NULL, fixed.estimates=TRUE, data=list(), subset=NULL, contrasts=NULL)
randomizedBlockFit(y,X,Z,w=NULL,fixed.estimates=TRUE)
}

\arguments{
The arguments \code{formula}, \code{weights}, \code{data}, \code{subset} and \code{contrasts} have the same meaning as in \code{lm}.
The arguments \code{y}, \code{X} and \code{w} have the same meaning as in \code{lm.wfit}.
\item{formula}{formula specifying the fixed model.}
\item{random}{vector or factor specifying the blocks corresponding to random effects.}
\item{weights}{optional vector of prior weights.}
\item{fixed.estimates}{should the fixed effect coefficients be returned?}
\item{data}{an optional data frame containing the variables in the model.}
\item{subset}{an optional vector specifying a subset of observations to be used in the fitting process.}
\item{contrasts}{an optional list. See the \code{contrasts.arg} of \code{model.matrix.default}.}
\item{y}{response vector.}
\item{X}{design matrix for fixed model.}
\item{Z}{design matrix for random effects.}
\item{w}{optional vector of prior weights.}
}

\details{
This function fits the model \eqn{y=Xb+Zu+e} where \eqn{b} is a vector of fixed coefficients and \eqn{u} is a vector of random effects.
Write \eqn{n} for the length of \eqn{y} and \eqn{q} for the length of \eqn{u}.
The random effect vector \eqn{u} is assumed to be normal, mean zero, with covariance matrix \eqn{\sigma^2_uI_q} while \eqn{e} is normal, mean zero, with covariance matrix \eqn{\sigma^2I_n}.
If \eqn{Z} is an indicator matrix, then this model corresponds to a randomized block experiment.
The model is fitted using an eigenvalue decomposition which transforms the problem into a Gamma generalized linear model.

This function is essentially equivalent to \code{lme(fixed=formula,random=~1|random)} but is more accurate and is much faster for small to moderate size data sets.

Missing values in the data are not allowed.
}

\value{A list with the components.
If \code{fixed.estimates=TRUE} then the components from \code{"lm.fit"} are also returned.
\item{sigmasquared}{vector of length two containing the residual and block components of variance.}
\item{se.sigmasquared}{standard errors for the components of variance.}
}

\author{Gordon Smyth}

\seealso{
\code{\link[nlme:lme]{lme}}, \code{\link[base:lm]{lm}}, \code{\link[base:lm]{lm.fit}}
}

\examples{
#  Compare with first data example from Venable and Ripley (2002), Chapter 10, "Linear Models"
library(MASS)
data(petrol)
out <- randomizedBlock(Y~SG+VP+V10+EP, random=No, data=petrol)
cbind(sigmasquared=out$sigmasquared,se=out$se.sigmasquared)
}

\keyword{regression}
\eof
\name{remlscore}
\alias{remlscore}
\title{REML for heteroscedastic regression}
\description{
Fits a heteroscedastic regression model using residual maximum likelihood (REML).
}
\usage{
remlscore(y, X, Z, trace=FALSE, tol=1e-5, maxit=40)
}
\arguments{
  \item{y}{numeric vector of responses}
  \item{X}{design matrix for predicting the mean}
  \item{Z}{design matrix for predicting the variance}
  \item{trace}{Logical variable. If true then output diagnostic information at each iteration.}
  \item{tol}{Convergence tolerance}
  \item{maxit}{Maximum number of iterations allowed}
}
\value{
List with the following components:
  \item{beta}{Vector of regression coefficients for predicting the mean}
  \item{se.beta}{<Standard errors for beta}
  \item{gamma}{Vector of regression coefficients for predicting the variance}
  \item{se.gam}{Standard errors for gamma}
  \item{mu}{Estimated means}
  \item{phi}{Estimated variances}
  \item{deviance}{Minus twice the REML log-likelihood}
  \item{h}{Leverages}
}
\item{details}
Write \eqn{\mu_i=E(y_i)} for the expectation of the $i$th response and $s_i=\var(y_i)$.
We assume the heteroscedastic regression model
\deqn{\mm_i=\bold{x}_i^T\bold{\beta}}
\deqn{\log(\sigma^2_i=\bold{z}_i^T\bold{\gamma},}
where $\bold{x}_i$ and $\bold{z}_i$ are vectors of covariates, and $\bold{\beta}$ and $\bold{\gamma}$ are vectors of regression coefficients affecting the mean and variance respectively.

Parameters are estimated by maximizing the REML likelihood using REML scoring as described in Smyth (2002).
}
\references{
Smyth, G. K. (2002). An efficient algorithm for REML in heteroscedastic regression. \emph{Journal of Computational and Graphical Statistics} \bold{11}, 1-12.
}
\examples{
data(welding)
attach(welding)
y <- Strength
# Reproduce results from Table 1 of Smyth (2002)
X <- cbind(1,(Drying+1)/2,(Material+1)/2)
colnames(X) <- c("1","B","C")
Z <- cbind(1,(Material+1)/2,(Method+1)/2,(Preheating+1)/2)
colnames(Z) <- c("1","C","H","I")
out <- remlscore(y,X,Z)
cbind(Estimate=out$gamma,SE=out$se.gam)
}
\keyword{regression}
\eof
\name{remlscoregamma}
\alias{remlscoregamma}
\title{Approximate REML for gamma regression with structured dispersion}
\description{
Estimates structured dispersion effects using approximate REML with gamma responses.
}
\usage{
remlscoregamma(y,X,Z,mlink="log",dlink="log",trace=FALSE,tol=1e-5,maxit=40)
}
\arguments{
  \item{y}{numeric vector of responses}
  \item{X}{design matrix for predicting the mean}
  \item{Z}{design matrix for predicting the variance}
  \item{mlink}{character string or numeric value specifying link for mean model}
  \item{dlink}{character string or numeric value specifying link for dispersion model}
  \item{trace}{Logical variable. If true then output diagnostic information at each iteration.}
  \item{tol}{Convergence tolerance}
  \item{maxit}{Maximum number of iterations allowed}
}
\value{
List with the following components:
  \item{beta}{Vector of regression coefficients for predicting the mean}
  \item{se.beta}{<Standard errors for beta}
  \item{gamma}{Vector of regression coefficients for predicting the variance}
  \item{se.gam}{Standard errors for gamma}
  \item{mu}{Estimated means}
  \item{phi}{Estimated dispersions}
  \item{deviance}{Minus twice the REML log-likelihood}
  \item{h}{Leverages}
}
\item{details}
Write \eqn{\mu_i=E(y_i)} for the expectation of the $i$th response and $s_i=\var(y_i)$.
We assume the heteroscedastic regression model
\deqn{\mm_i=\bold{x}_i^T\bold{\beta}}
\deqn{\log(\sigma^2_i=\bold{z}_i^T\bold{\gamma},}
where $\bold{x}_i$ and $\bold{z}_i$ are vectors of covariates, and $\bold{\beta}$ and $\bold{\gamma}$ are vectors of regression coefficients affecting the mean and variance respectively.

Parameters are estimated by maximizing the REML likelihood using REML scoring as described in Smyth (2002).
}
\references{
Smyth, G. K., and Verbyla, A. P. (2002). Leverage adjustments for dispersion modelling in generalized nonlinear models.
}
\examples{
data(welding)
attach(welding)
y <- Strength
X <- cbind(1,(Drying+1)/2,(Material+1)/2)
colnames(X) <- c("1","B","C")
Z <- cbind(1,(Material+1)/2,(Method+1)/2,(Preheating+1)/2)
colnames(Z) <- c("1","C","H","I")
out <- remlscoregamma(y,X,Z)
}
\keyword{regression}
\eof
\name{sage.test}
\alias{sage.test}

\title{Compare Two SAGE Libraries}
\description{
Compute a p-values for differential expression for each tag between two SAGE libraries. 
}

\usage{
sage.test(x, y, n1=sum(x), n2=sum(y))
}

\arguments{
\item{x}{integer vector giving counts in first library}
\item{y}{integer vector giving counts in second library}
\item{n1}{total number of tags in first library}
\item{n2}{total number of tags in second library}
}

\details{
This function uses a binomial approximation to the Fisher Exact test for each tag.
This will be accurate when the total number of tags is large.
}

\value{
Numeric vector of p-values.
}

\author{Gordon Smyth}

\seealso{
\code{\link{fisher.test2}}, \code{\link[ctest]{fisher.test}}
}

\examples{
sage.test(c(0,5,10),c(0,30,50),n1=10000,n2=15000)
}

\keyword{htest}
\eof
\name{tweedie}
\alias{tweedie}
\title{Tweedie Generalized Linear Models}

\description{
Produces a generalized linear model family object with any power variance function and any power link. Includes the Gaussian, Poisson, gamma and inverse-Gaussian families as special cases.
}
\usage{
tweedie(var.power=0, link.power=1-var.power)
}

\arguments{
\item{var.power}{index of power variance function}
\item{link.power}{index of power link function. \code{link.power=0} produces a log-link. Defaults to the canonical link, which is \code{1-var.power}.} 
}

\value{
A family object, which is a list of functions and expressions used by glm and gam in their iteratively reweighted least-squares algorithms.
See \code{family} and \code{glm} in the R base help for details. 
}

\details{
This function provides access to a range of generalized linear model response distributions which are not otherwise provided by R, or any other package for that matter. It is also useful for accessing distribution/link combinations which are disallowed by the R \code{glm} function.

Let \eqn{\mu_i = E(y_i)} be the expectation of the \eqn{i}th response. We assume that
\deqn{\mu_i^q = x_i^Tb, var(y_i) = \phi \mu_i^p} 

where \eqn{x_i} is a vector of covariates and b is a vector of regression cofficients, for some \eqn{\phi}, \eqn{p} and \eqn{q}. This family is specified by \code{var.power = p} and \code{link.power = q}. A value of zero for \eqn{q} is interpreted as \eqn{\log(\mu_i) = x_i^Tb}. 

The variance power \eqn{p} characterizes the distribution of the responses \eqn{y}. The following are some special cases:

\tabular{cl}{
\bold{p} \tab \bold{Response distribution}\cr
0 \tab Normal\cr
1 \tab Poisson\cr
(1, 2) \tab Compound Poisson, non-negative with mass at zero\cr
2 \tab Gamma\cr
3 \tab Inverse-Gaussian\cr
> 2 \tab Stable, with support on the positive reals
}

The name Tweedie has been associated with this family by Jrgensen in honour of M. C. K. Tweedie. 
}
 
\references{
Tweedie, M. C. K. (1984). An index which distinguishes between some important exponential families. In \emph{Statistics: Applications and New Directions}. Proceedings of the Indian Statistical Institute Golden Jubilee International Conference. (Eds. J. K. Ghosh and J. Roy), pp. 579-604. Calcutta: Indian Statistical Institute.

Jrgensen, B. (1987). Exponential dispersion models. \emph{J. R. Statist. Soc.} B \bold{49}, 127-162. 

Smyth, G. K. (1996). Regression modelling of quantity data with exact zeroes. Proceedings of the Second Australia-Japan Workshop on Stochastic Models in Engineering, Technology and Management. Technology Management Centre, University of Queensland, pp. 572-580. 

Jrgensen, B. (1997). \emph{Theory of Dispersion Models}, Chapman and Hall, London. 

Smyth, G. K., and Verbyla, A. P., (1999). Adjusted likelihood methods for modelling dispersion in generalized linear models. \emph{Environmetrics} \bold{10}, 695-709. 
}

\author{Gordon Smyth}

\seealso{\code{\link[base]{glm}}, \code{\link[base]{family}}, \code{\link[tweedie]{dtweedie}}}

\examples{
y <- rgamma(20,shape=5)
x <- 1:20
# Fit a poisson generalized linear model with identity link
glm(y~x,family=tweedie(var.power=1,link.power=1))

# Fit an inverse-Gaussion glm with log-link
glm(y~x,family=tweedie(var.power=3,link.power=0)) 
}

\keyword{regression}
\eof
\name{welding}
\alias{welding}
\title{Data: Tensile Strength of Welds}
\description{
This is a highly fractionated two-level factorial design employed as a screening design
in an off-line welding experiment performed by the National Railway Corporation of Japan.
There were 16 runs and 9 experimental factors. The response variable is the observed
tensile strength of the weld, one of several quality characteristics measured. All other
variables are at plus and minus levels.
}
\usage{data(welding)}
\format{
A data frame containing the variables.
All the explanatory variables are numeric with two levels, \code{-1} and \code{1}.
  \item{Rods}{Kind of welding rods}
  \item{Drying}{Period of drying}
  \item{Material}{Welded material}
  \item{Thickness}{Thickness}
  \item{Angle}{Angle}
  \item{Opening}{Opening}
  \item{Current}{Current}
  \item{Method}{Welding method}
  \item{Preheating}{Preheating}
  \item{Strength}{Tensile strength of the weld in kg/mm. The response variable.}
}
\source{
\url{http://www.statsci.org/data/general/welding.html}
}
\references{
Smyth, G. K., Huele, F., and Verbyla, A. P. (2001). Exact and approximate REML for heteroscedastic regression. \emph{Statistical Modelling} \bold{1}, 161-175.

Smyth, G. K. (2002). An efficient algorithm for REML in heteroscedastic regression. \emph{Journal of Computational and Graphical Statistics} \bold{11}, 1-12.
}
\keyword{datasets}
\eof
